@@ -63,7 +63,7 @@ def is_parent_process_alive():
             return True
     else:
         try:
-            return psutil.pid_exists()
+            return psutil.pid_exists(parent_pid)
         except (AttributeError, KeyboardInterrupt, Exception):
             return False
 
@@ -470,7 +470,7 @@ class OperationProcess(ContinuousProcess):
         """Try to get data from the queue and run the operation."""
         try:
             # Wait for data and other arguments
-            op_args, op_kwargs = self._operations.get(timeout=self._timeout)
+            op_args, op_kwargs = self._operations.get(timeout=self.timeout)
 
             # Check for an internal command
             if "INTERNAL_PROCESS_COMMAND" in op_kwargs:
